import { __rest, __assign } from 'tslib';
import React, { createContext, useContext, useState, useEffect } from 'react';
import { useRouter } from 'next/router';
import rosetta from 'rosetta';

/**
 * Use <I18nProvider /> instead of this internal context.
 */
var I18nContext = createContext(null);
/**
 * @example <caption>Simple</caption>
 * const { t } = useI18n()
 * const text = t("title")
 * @example <caption>With types</caption>
 * interface LocaleTable { title: string; }
 * const { t } = useI18n<LocaleTable>()
 * const text = t("title")
 */
function useI18n() {
    var instance = useContext(I18nContext);
    if (!instance) {
        throw new Error("There was an error getting i18n instance from context");
    }
    return instance;
}
/**
 * You probably want to add this at the root of your project. If you are using Next.js add it to `_app.tsx`.
 */
function I18nProvider(_a) {
    var table = _a.table, props = __rest(_a, ["table"]);
    var locale = useRouter().locale;
    var _b = useState(function () {
        // Initial state
        var current = rosetta();
        // const current = rosettaExtended<T>();
        current.set(locale, table);
        current.locale(locale);
        return current;
    }), i18n = _b[0], setI18n = _b[1];
    var hasChanged = i18n.locale() !== locale;
    useEffect(function () {
        var current = rosetta();
        current.set(locale, table);
        current.locale(locale);
        setI18n(current);
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [hasChanged, table]);
    return React.createElement(I18nContext.Provider, __assign({ value: i18n }, props));
}

export { I18nContext, I18nProvider, useI18n };
//# sourceMappingURL=next-rosetta.esm.js.map
